# -*- coding: utf-8 -*-
# Part of Odoo. See LICENSE file for full copyright and licensing details.

from . import phone_blacklist
from . import mail_thread_phone
from . import models
from . import res_partner
from . import res_users
